@@ -49,6 +49,7 @@
  */
 #define KEY_TITLEBAR_FONT "/apps/metacity/general/titlebar_font"
 #define KEY_NUM_WORKSPACES "/apps/metacity/general/num_workspaces"
+#define KEY_COMPOSITOR "/apps/metacity/general/compositing_manager"
 #define KEY_GNOME_ACCESSIBILITY "/desktop/gnome/interface/accessibility"
 
 #define KEY_COMMAND_PREFIX "/apps/metacity/keybinding_commands/command_"
@@ -1928,6 +1929,7 @@ static MetaKeyPref window_bindings[] = {
   { META_KEYBINDING_MOVE_TO_SIDE_S, NULL, FALSE },
   { META_KEYBINDING_MOVE_TO_SIDE_E, NULL, FALSE },
   { META_KEYBINDING_MOVE_TO_SIDE_W, NULL, FALSE },
+  { META_KEYBINDING_MOVE_TO_CENTER, NULL, FALSE },
   { NULL, NULL, FALSE }
 };
 
@@ -2944,6 +2946,24 @@ meta_prefs_get_compositing_manager (void)
   return compositing_manager;
 }
 
+void
+meta_prefs_set_compositing_manager (gboolean whether)
+{
+  GError *err = NULL;
+
+  gconf_client_set_bool (default_client,
+                         KEY_COMPOSITOR,
+                         whether,
+                         &err);
+
+  if (err)
+    {
+      meta_warning (_("Error setting compositor status: %s\n"),
+                    err->message);
+      g_error_free (err);
+    }
+}
+
 #ifndef HAVE_GCONF
 static void
 init_button_layout(void)
